# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

## [0.0.1] - 2024-05-16

### Added

- Knob class to represent tunable values
- Python package infrastructure
- Shorthand run function to start the terminal application
- Small two-value example
- Terminal user interface based on [Textual](https://textual.textualize.io/)
- Unit tests for the Knob class
- Unit tests for the terminal user interface

[unreleased]: https://github.com/qpsolvers/qpsolvers/compare/v0.0.1...HEAD
[0.0.1]: https://github.com/qpsolvers/qpsolvers/releases/tag/v0.0.1
